@@ -7,10 +7,19 @@ class RowException(Exception):
         return self.message_error
 
 
-class ConnectException(Exception):
+class ConnectExceptionLogin(Exception):
 
     def __init__(self):
-        self.message_error = 'Для подключения укажите корректно сервер, базу данных, схему и таблицу!'
+        self.message_error = 'Для подключения укажите корректно логин и пароль пользователя!'
+
+    def __str__(self):
+        return self.message_error
+
+
+class ConnectExceptionToken(Exception):
+
+    def __init__(self):
+        self.message_error = 'Для подключения укажите корректные данные секретного токена!'
 
     def __str__(self):
         return self.message_error
