@@ -14,7 +14,7 @@ class GetterData:
     def __init__(self):
         self.connection = None
         self.connect_data = self.get_connect_data()
-        self.self_path = os.path.dirname(__file__)
+        self.self_path = os.path.abspath(os.curdir)
         try:
             self.settings = self.read_settings()
         except Exception:
@@ -28,13 +28,15 @@ class GetterData:
             settings: dict
                 Словарь содержащий в себе компоненты необходимые для выгрузки данных
         """
-        with open(os.path.join(self.self_path, "settings.json")) as file:
+        with open(os.path.join(self.self_path, "settings.json"), 'r') as file:
             settings = json.load(file)
         return settings
 
-    def write_settings(self, prefix_login='', url='', cert_vault_tls='', cert_vault_key='', cert_vault_verify=''):
+    def write_secret_token_settings(self, prefix_login='', url='', cert_vault_tls='', cert_vault_key='',
+                                    cert_vault_verify='', vault_token='', vault_secret_engine='',
+                                    vault_path=''):
         """
-        Функция создания файла настроек
+        Функция создания файла настроек с сикретным токеном
 
         Parameters
         ------------
@@ -48,12 +50,41 @@ class GetterData:
                 Путь до ключа сертификата
             cert_vault_verify: str
                 Путь до верификации сертификата
+            vault_token: str
+                Vault токен
+            vault_secret_engine: str
+                Названиие используемого Secret Engine
+            vault_path: str
+                Путь до секрета в Vault
         """
         settings_to_json = {'prefix_login': prefix_login,
                             'url': url,
                             'cert_vault_tls': cert_vault_tls,
                             'cert_vault_key': cert_vault_key,
-                            'cert_vault_verify': cert_vault_verify, }
+                            'cert_vault_verify': cert_vault_verify,
+                            'vault_token': vault_token,
+                            'vault_secret_engine': vault_secret_engine,
+                            'vault_path': vault_path, }
+
+        with open((os.path.join(self.self_path, "settings.json")), 'w') as file:
+            json.dump(settings_to_json, file)
+
+    def write_login_settings(self, prefix_login='', login='', password=''):
+        """
+        Функция создания файла настроек с логином и паролем
+
+        Parameters
+        ------------
+            prefix_login: str
+                Префикс для логина (если не требуется добавьте поле и передайте пустую строку)
+            login: str
+                Логин пользователя
+            password: str
+                Пароль пользователя
+        """
+        settings_to_json = {'prefix_login': prefix_login,
+                            'login': login,
+                            'password': password, }
 
         with open((os.path.join(self.self_path, "settings.json")), 'w') as file:
             json.dump(settings_to_json, file)
@@ -77,68 +108,54 @@ class GetterData:
             print("Не удалось считать данные для подключения в автоматическом режиме, введите их пожалуйста вручную!")
         return connect_data
 
-    def connect_to_db_with_login(self, login, password):
+    def connect_to_db_with_login(self):
         """
         Функция для подключения к базе данных с использованием логином и пароля
-
-        Parameters
-        ------------
-            login: str
-                Логин для подключения к базе данных
-            password: str
-                Пароль для подключения к базе данных
         Raises
         -------------
             ConnectException
                 Исключение, вызываемое при отсутствии данных для подключения к базе (сервер, база данных, схема, таблица)
         """
-        if len(self.connect_data) > 0:
-            self.connect_data['username'] = self.settings['prefix_login'] + login
-            self.connect_data['password'] = password
+        if "login" in self.settings.keys() and "password" in self.settings.keys():
+            self.connect_data['username'] = self.settings['prefix_login'].replace('/', '\\') + self.settings['login']
+            self.connect_data['password'] = self.settings['password']
             self.connection = pymssql.connect(self.connect_data["server"],
                                               self.connect_data["username"],
                                               self.connect_data["password"],
                                               self.connect_data["database"])
         else:
-            raise ConnectException
+            raise ConnectExceptionLogin
 
-    def connect_to_db_with_token(self, vault_token, vault_secret_engine, vault_path):
+    def connect_to_db_with_token(self):
         """
         Функция для подключения к базе данных с использованием библиотеки hvac
 
-        Parameters
-        ------------
-            vault_token: str
-                Vault токен
-            vault_secret_engine: str
-                Названиие используемого Secret Engine
-            vault_path: str
-                Путь до секрета в Vault
         Raises
         -------------
             ConnectException
                 Исключение, вызываемое при отсутствии данных для подключения к базе (сервер, база данных, схема, таблица)
         """
-        if len(self.connect_data) > 0:
+        if "url" in self.settings.keys() and "cert_vault_tls" in self.settings.keys() and \
+                "cert_vault_key" in self.settings.keys() and "cert_vault_verify" in self.settings.keys():
 
             cli = hvac.Client(url=self.settings['url'],
-                              token=vault_token,
+                              token=self.settings['vault_token'],
                               cert=(self.settings["cert_vault_tls"], self.settings["cert_vault_key"]),
                               verify=self.settings["cert_vault_verify"])
             if cli.is_authenticated():
-                creds = cli.secrets.kv.v2.read_secret_version(mount_point=vault_secret_engine, path=vault_path).get(
-                    "data").get("data")
+                creds = cli.secrets.kv.v2.read_secret_version(mount_point=self.settings['vault_secret_engine'],
+                                                              path=self.settings['vault_path']).get("data").get("data")
 
                 login = creds.get('username')
                 password = creds.get('password')
-                self.connect_data['username'] = self.settings['prefix_login'] + login
+                self.connect_data['username'] = self.settings['prefix_login'].replace('/', '\\') + login
                 self.connect_data['password'] = password
                 self.connection = pymssql.connect(self.connect_data["server"],
                                                   self.connect_data["username"],
                                                   self.connect_data["password"],
                                                   self.connect_data["database"])
         else:
-            raise ConnectException
+            raise ConnectExceptionToken
 
     def get_data_weather(self, row=None):
         """
